@@ -4,7 +4,7 @@
  * Declarations relating to support for wide characters; many are simply
  * inherited by (sub-optimal) inclusion of other header files.
  *
- * $Id: wchar.h,v 48606679ec51 2020/03/03 21:58:11 keith $
+ * $Id: wchar.h,v 3346bd5e5239 2020/07/04 21:06:58 keith $
  *
  * Unattributed original source.
  * Adapted by Rob Savoye <rob@cygnus.com>
@@ -534,7 +534,7 @@ typedef int mbstate_t;
  * maybe also in some earlier non-free DLLs, such as MSVCP60.DLL and
  * later); they are also available in MSVCRT.DLL, from Vista onward,
  * but to provide continuing support for earlier Windows versions,
- * we invoke them via MinGW specific wrappers, defined below.
+ * we always use MinGW replacements, provided in libmingwex.a
  */
 __cdecl __MINGW_NOTHROW  wint_t btowc (int);
 __cdecl __MINGW_NOTHROW  int wctob (wint_t);
@@ -554,91 +554,6 @@ __cdecl __MINGW_NOTHROW  size_t wcrtomb
 __cdecl __MINGW_NOTHROW  size_t wcsrtombs
 (char *__restrict__, const wchar_t **__restrict__, size_t, mbstate_t *__restrict__);
 
-/* To provide support for the above, on legacy Windows versions,
- * we implement fall back wrappers in libmingwex.a; each of these
- * will delegate to the corresponding Microsoft implementation, if
- * it exists in the process address space; otherwise, execution
- * will fall back to a MinGW implementation...
- */
-__cdecl __MINGW_NOTHROW  wint_t __msvcrt_btowc (int);
-
-__cdecl __MINGW_NOTHROW  size_t __msvcrt_mbrlen
-(const char *__restrict__, size_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  size_t __msvcrt_mbrtowc
-(wchar_t *__restrict__, const char *__restrict__, size_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  size_t __msvcrt_mbsrtowcs
-(wchar_t *__restrict__, const char **__restrict__, size_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  int __msvcrt_wctob (wint_t);
-
-__cdecl __MINGW_NOTHROW  size_t __msvcrt_wcrtomb
-(char * __restrict__, wchar_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  size_t __msvcrt_wcsrtombs
-(char *__restrict__, const wchar_t **__restrict__, size_t, mbstate_t *__restrict__);
-
-/* ...whereas, these alternatives will always invoke the MinGW
- * fall back implementations, without considering any possible
- * reference to MSVCRT.DLL or MSVCR80.DLL implementations.
- */
-__cdecl __MINGW_NOTHROW  wint_t __mingw_btowc (int);
-
-__cdecl __MINGW_NOTHROW  size_t __mingw_mbrlen
-(const char *__restrict__, size_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  size_t __mingw_mbrtowc
-(wchar_t *__restrict__, const char *__restrict__, size_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  size_t __mingw_mbsrtowcs
-(wchar_t *__restrict__, const char **__restrict__, size_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  int __mingw_wctob (wint_t);
-
-__cdecl __MINGW_NOTHROW  size_t __mingw_wcrtomb
-(char * __restrict__, wchar_t, mbstate_t *__restrict__);
-
-__cdecl __MINGW_NOTHROW  size_t __mingw_wcsrtombs
-(char *__restrict__, const wchar_t **__restrict__, size_t, mbstate_t *__restrict__);
-
-#if __MSVCRT_VERSION__ < __MSVCR80_DLL
-/* FIXME: Maybe consider these mappings, even for linking with the
- * non-free MSVCR80.DLL, and its descendants.
- *
- * For linking with all versions of MSVCRT.DLL, and with non-free
- * alternatives predating MSVCR80.DLL, we enforce inline mapping to
- * the libmingwex.a implementations, (which will delegate the calls
- * to the Microsoft DLL implementations, when they are available).
- */
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  wint_t btowc (int __c)
-{ return __msvcrt_btowc( __c ); }
-
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  size_t mbrlen
-(const char *__mbc, size_t __n, mbstate_t *__ps)
-{ return __msvcrt_mbrlen( __mbc, __n, __ps ); }
-
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  size_t mbrtowc
-(wchar_t *__wc, const char *__mbc, size_t __n, mbstate_t *__ps)
-{ return __msvcrt_mbrtowc( __wc, __mbc, __n, __ps ); }
-
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  size_t mbsrtowcs
-(wchar_t *__wcs, const char **__mbs, size_t __n, mbstate_t *__ps)
-{ return __msvcrt_mbsrtowcs( __wcs, __mbs, __n, __ps ); }
-
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  int wctob (wint_t __wc)
-{ return __msvcrt_wctob( __wc ); }
-
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  size_t wcrtomb
-(char * __mbc, wchar_t __wc, mbstate_t *__ps)
-{ return __msvcrt_wcrtomb(__mbc, __wc, __ps); }
-
-__CRT_ALIAS __cdecl __MINGW_NOTHROW  size_t wcsrtombs
-(char *__mbs, const wchar_t **__wcs, size_t __len, mbstate_t *__ps)
-{ return __msvcrt_wcsrtombs(__mbs, __wcs, __len, __ps); }
-
-#endif	/* ! MSVCR80.DLL or later */
-
 #if defined _ISOC99_SOURCE || defined __cplusplus
 /* These ISO-C99 functions are implemented in libmingwex.a,
  * or, in some cases, as inline stubs; while provided as MinGW
@@ -649,13 +564,13 @@ __cdecl __MINGW_NOTHROW  int fwide (FILE *, int);
 __cdecl __MINGW_NOTHROW  int mbsinit (const mbstate_t *);
 
 #ifndef __NO_INLINE__
-__CRT_INLINE __cdecl __MINGW_NOTHROW
-int fwide (FILE *__UNUSED_PARAM(stream), int mode)
-  { return mode; } /* Nothing to do  */
+__CRT_INLINE __LIBIMPL__(( FUNCTION = fwide ))
+__cdecl __MINGW_NOTHROW  int fwide (FILE *__UNUSED_PARAM(__stream), int __mode)
+{ return __mode; } /* Nothing to do  */
 
-__CRT_INLINE __cdecl __MINGW_NOTHROW
-int mbsinit (const mbstate_t *__UNUSED_PARAM(ps))
-  { return 1; }
+__CRT_INLINE __LIBIMPL__(( FUNCTION = mbsinit ))
+__cdecl __MINGW_NOTHROW  int mbsinit (const mbstate_t *__ps)
+{ return ((__ps == NULL) || (*__ps == (mbstate_t)(0))); }
 #endif
 
 __cdecl __MINGW_NOTHROW  wchar_t *wmemset (wchar_t *, wchar_t, size_t);
