@@ -5,10 +5,10 @@
  * may also be invoked inline, as "retval = setenv( varname, NULL, 1 )",
  * to implement the complementary unsetenv() function.
  *
- * $Id: setenv.c,v fc596db3d3b4 2016/11/28 14:14:48 keithmarshall $
+ * $Id: setenv.c,v 45600656c558 2021/01/26 19:58:39 keith $
  *
- * Written by Keith Marshall <keithmarshall@users.sourceforge.net>
- * Copyright (C) 2016, MinGW.org Project
+ * Written by Keith Marshall <keith@users.osdn.me>
+ * Copyright (C) 2016, 2021, MinGW.org Project
  *
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -64,8 +64,8 @@ int __mingw_setenv( const char *var, const char *value, int overwrite )
        */
       const char *fmt = "%s=%s";
       const char *val = value ? value : "";
-      char buf[1 + snprintf( NULL, 0, fmt, var, val )];
-      snprintf( buf, sizeof( buf ), fmt, var, val );
+      char buf[1 + __mingw_snprintf( NULL, 0, fmt, var, val )];
+      __mingw_snprintf( buf, sizeof( buf ), fmt, var, val );
 
       /* "buf" is now formatted as "var=value", in the form
        * required by putenv(), but it exists only within our
